/* LastImportPage.c generated by valac 0.32.1, the Vala compiler
 * generated from LastImportPage.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>


#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;
typedef struct _PagePrivate PagePrivate;

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_FULLSCREEN_WINDOW (fullscreen_window_get_type ())
#define FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindow))
#define FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))
#define IS_FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FULLSCREEN_WINDOW))
#define IS_FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FULLSCREEN_WINDOW))
#define FULLSCREEN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))

typedef struct _FullscreenWindow FullscreenWindow;
typedef struct _FullscreenWindowClass FullscreenWindowClass;

#define TYPE_INJECTION_GROUP (injection_group_get_type ())
#define INJECTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INJECTION_GROUP, InjectionGroup))
#define INJECTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INJECTION_GROUP, InjectionGroupClass))
#define IS_INJECTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INJECTION_GROUP))
#define IS_INJECTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INJECTION_GROUP))
#define INJECTION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INJECTION_GROUP, InjectionGroupClass))

typedef struct _InjectionGroup InjectionGroup;
typedef struct _InjectionGroupClass InjectionGroupClass;

#define TYPE_CHECKERBOARD_PAGE (checkerboard_page_get_type ())
#define CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPage))
#define CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))
#define IS_CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_PAGE))
#define IS_CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_PAGE))
#define CHECKERBOARD_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))

typedef struct _CheckerboardPage CheckerboardPage;
typedef struct _CheckerboardPageClass CheckerboardPageClass;
typedef struct _CheckerboardPagePrivate CheckerboardPagePrivate;

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_VIEW (data_view_get_type ())
#define DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_VIEW, DataView))
#define DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_VIEW, DataViewClass))
#define IS_DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_VIEW))
#define IS_DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_VIEW))
#define DATA_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_VIEW, DataViewClass))

typedef struct _DataView DataView;
typedef struct _DataViewClass DataViewClass;

#define TYPE_THUMBNAIL_VIEW (thumbnail_view_get_type ())
#define THUMBNAIL_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_VIEW, ThumbnailView))
#define THUMBNAIL_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_VIEW, ThumbnailViewClass))
#define IS_THUMBNAIL_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_VIEW))
#define IS_THUMBNAIL_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_VIEW))
#define THUMBNAIL_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_VIEW, ThumbnailViewClass))

typedef struct _ThumbnailView ThumbnailView;
typedef struct _ThumbnailViewClass ThumbnailViewClass;

#define TYPE_CHECKERBOARD_ITEM (checkerboard_item_get_type ())
#define CHECKERBOARD_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_ITEM, CheckerboardItem))
#define CHECKERBOARD_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_ITEM, CheckerboardItemClass))
#define IS_CHECKERBOARD_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_ITEM))
#define IS_CHECKERBOARD_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_ITEM))
#define CHECKERBOARD_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_ITEM, CheckerboardItemClass))

typedef struct _CheckerboardItem CheckerboardItem;
typedef struct _CheckerboardItemClass CheckerboardItemClass;

#define CHECKERBOARD_PAGE_TYPE_ACTIVATOR (checkerboard_page_activator_get_type ())

#define CHECKERBOARD_PAGE_TYPE_KEYBOARD_MODIFIERS (checkerboard_page_keyboard_modifiers_get_type ())
typedef struct _CheckerboardPageKeyboardModifiers CheckerboardPageKeyboardModifiers;

#define TYPE_VIEW_FILTER (view_filter_get_type ())
#define VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_FILTER, ViewFilter))
#define VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_FILTER, ViewFilterClass))
#define IS_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_FILTER))
#define IS_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_FILTER))
#define VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_FILTER, ViewFilterClass))

typedef struct _ViewFilter ViewFilter;
typedef struct _ViewFilterClass ViewFilterClass;

#define TYPE_SEARCH_VIEW_FILTER (search_view_filter_get_type ())
#define SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SEARCH_VIEW_FILTER, SearchViewFilter))
#define SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SEARCH_VIEW_FILTER, SearchViewFilterClass))
#define IS_SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SEARCH_VIEW_FILTER))
#define IS_SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SEARCH_VIEW_FILTER))
#define SEARCH_VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SEARCH_VIEW_FILTER, SearchViewFilterClass))

typedef struct _SearchViewFilter SearchViewFilter;
typedef struct _SearchViewFilterClass SearchViewFilterClass;

#define CORE_TYPE_TRACKER (core_tracker_get_type ())
#define CORE_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CORE_TYPE_TRACKER, CoreTracker))
#define CORE_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CORE_TYPE_TRACKER, CoreTrackerClass))
#define CORE_IS_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CORE_TYPE_TRACKER))
#define CORE_IS_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CORE_TYPE_TRACKER))
#define CORE_TRACKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CORE_TYPE_TRACKER, CoreTrackerClass))

typedef struct _CoreTracker CoreTracker;
typedef struct _CoreTrackerClass CoreTrackerClass;

#define CORE_TYPE_VIEW_TRACKER (core_view_tracker_get_type ())
#define CORE_VIEW_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CORE_TYPE_VIEW_TRACKER, CoreViewTracker))
#define CORE_VIEW_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CORE_TYPE_VIEW_TRACKER, CoreViewTrackerClass))
#define CORE_IS_VIEW_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CORE_TYPE_VIEW_TRACKER))
#define CORE_IS_VIEW_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CORE_TYPE_VIEW_TRACKER))
#define CORE_VIEW_TRACKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CORE_TYPE_VIEW_TRACKER, CoreViewTrackerClass))

typedef struct _CoreViewTracker CoreViewTracker;
typedef struct _CoreViewTrackerClass CoreViewTrackerClass;

#define TYPE_MEDIA_PAGE (media_page_get_type ())
#define MEDIA_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_PAGE, MediaPage))
#define MEDIA_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_PAGE, MediaPageClass))
#define IS_MEDIA_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_PAGE))
#define IS_MEDIA_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_PAGE))
#define MEDIA_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_PAGE, MediaPageClass))

typedef struct _MediaPage MediaPage;
typedef struct _MediaPageClass MediaPageClass;
typedef struct _MediaPagePrivate MediaPagePrivate;

#define TYPE_RATING (rating_get_type ())

#define TYPE_RAW_DEVELOPER (raw_developer_get_type ())

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_COLLECTION_PAGE (collection_page_get_type ())
#define COLLECTION_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COLLECTION_PAGE, CollectionPage))
#define COLLECTION_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COLLECTION_PAGE, CollectionPageClass))
#define IS_COLLECTION_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COLLECTION_PAGE))
#define IS_COLLECTION_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COLLECTION_PAGE))
#define COLLECTION_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COLLECTION_PAGE, CollectionPageClass))

typedef struct _CollectionPage CollectionPage;
typedef struct _CollectionPageClass CollectionPageClass;
typedef struct _CollectionPagePrivate CollectionPagePrivate;

#define TYPE_LAST_IMPORT_PAGE (last_import_page_get_type ())
#define LAST_IMPORT_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LAST_IMPORT_PAGE, LastImportPage))
#define LAST_IMPORT_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LAST_IMPORT_PAGE, LastImportPageClass))
#define IS_LAST_IMPORT_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LAST_IMPORT_PAGE))
#define IS_LAST_IMPORT_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LAST_IMPORT_PAGE))
#define LAST_IMPORT_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LAST_IMPORT_PAGE, LastImportPageClass))

typedef struct _LastImportPage LastImportPage;
typedef struct _LastImportPageClass LastImportPageClass;
typedef struct _LastImportPagePrivate LastImportPagePrivate;

#define TYPE_IMPORT_ID (import_id_get_type ())
typedef struct _ImportID ImportID;

#define TYPE_ALTERATION (alteration_get_type ())
#define ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ALTERATION, Alteration))
#define ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ALTERATION, AlterationClass))
#define IS_ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ALTERATION))
#define IS_ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ALTERATION))
#define ALTERATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ALTERATION, AlterationClass))

typedef struct _Alteration Alteration;
typedef struct _AlterationClass AlterationClass;

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;

#define TYPE_MEDIA_SOURCE_COLLECTION (media_source_collection_get_type ())
#define MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection))
#define MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))
#define IS_MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_COLLECTION))
#define IS_MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_COLLECTION))
#define MEDIA_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))

typedef struct _MediaSourceCollection MediaSourceCollection;
typedef struct _MediaSourceCollectionClass MediaSourceCollectionClass;

#define TYPE_MEDIA_COLLECTION_REGISTRY (media_collection_registry_get_type ())
#define MEDIA_COLLECTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistry))
#define MEDIA_COLLECTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistryClass))
#define IS_MEDIA_COLLECTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_COLLECTION_REGISTRY))
#define IS_MEDIA_COLLECTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_COLLECTION_REGISTRY))
#define MEDIA_COLLECTION_REGISTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistryClass))

typedef struct _MediaCollectionRegistry MediaCollectionRegistry;
typedef struct _MediaCollectionRegistryClass MediaCollectionRegistryClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _media_collection_registry_unref0(var) ((var == NULL) ? NULL : (var = (media_collection_registry_unref (var), NULL)))
#define _data_collection_unref0(var) ((var == NULL) ? NULL : (var = (data_collection_unref (var), NULL)))
#define _alteration_unref0(var) ((var == NULL) ? NULL : (var = (alteration_unref (var), NULL)))

#define TYPE_VIEW_COLLECTION (view_collection_get_type ())
#define VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_COLLECTION, ViewCollection))
#define VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_COLLECTION, ViewCollectionClass))
#define IS_VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_COLLECTION))
#define IS_VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_COLLECTION))
#define VIEW_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_COLLECTION, ViewCollectionClass))

typedef struct _ViewCollection ViewCollection;
typedef struct _ViewCollectionClass ViewCollectionClass;
#define _import_id_free0(var) ((var == NULL) ? NULL : (var = (import_id_free (var), NULL)))

#define TYPE_VIEW_MANAGER (view_manager_get_type ())
#define VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_MANAGER, ViewManager))
#define VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_MANAGER, ViewManagerClass))
#define IS_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_MANAGER))
#define IS_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_MANAGER))
#define VIEW_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_MANAGER, ViewManagerClass))

typedef struct _ViewManager ViewManager;
typedef struct _ViewManagerClass ViewManagerClass;

#define VIEW_COLLECTION_TYPE_MONITOR (view_collection_monitor_get_type ())
#define VIEW_COLLECTION_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VIEW_COLLECTION_TYPE_MONITOR, ViewCollectionMonitor))
#define VIEW_COLLECTION_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VIEW_COLLECTION_TYPE_MONITOR, ViewCollectionMonitorClass))
#define VIEW_COLLECTION_IS_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VIEW_COLLECTION_TYPE_MONITOR))
#define VIEW_COLLECTION_IS_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VIEW_COLLECTION_TYPE_MONITOR))
#define VIEW_COLLECTION_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VIEW_COLLECTION_TYPE_MONITOR, ViewCollectionMonitorClass))

typedef struct _ViewCollectionMonitor ViewCollectionMonitor;
typedef struct _ViewCollectionMonitorClass ViewCollectionMonitorClass;

#define TYPE_COLLECTION_VIEW_MANAGER (collection_view_manager_get_type ())
#define COLLECTION_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COLLECTION_VIEW_MANAGER, CollectionViewManager))
#define COLLECTION_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COLLECTION_VIEW_MANAGER, CollectionViewManagerClass))
#define IS_COLLECTION_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COLLECTION_VIEW_MANAGER))
#define IS_COLLECTION_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COLLECTION_VIEW_MANAGER))
#define COLLECTION_VIEW_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COLLECTION_VIEW_MANAGER, CollectionViewManagerClass))

typedef struct _CollectionViewManager CollectionViewManager;
typedef struct _CollectionViewManagerClass CollectionViewManagerClass;

#define LAST_IMPORT_PAGE_TYPE_LAST_IMPORT_VIEW_MANAGER (last_import_page_last_import_view_manager_get_type ())
#define LAST_IMPORT_PAGE_LAST_IMPORT_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LAST_IMPORT_PAGE_TYPE_LAST_IMPORT_VIEW_MANAGER, LastImportPageLastImportViewManager))
#define LAST_IMPORT_PAGE_LAST_IMPORT_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LAST_IMPORT_PAGE_TYPE_LAST_IMPORT_VIEW_MANAGER, LastImportPageLastImportViewManagerClass))
#define LAST_IMPORT_PAGE_IS_LAST_IMPORT_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LAST_IMPORT_PAGE_TYPE_LAST_IMPORT_VIEW_MANAGER))
#define LAST_IMPORT_PAGE_IS_LAST_IMPORT_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LAST_IMPORT_PAGE_TYPE_LAST_IMPORT_VIEW_MANAGER))
#define LAST_IMPORT_PAGE_LAST_IMPORT_VIEW_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LAST_IMPORT_PAGE_TYPE_LAST_IMPORT_VIEW_MANAGER, LastImportPageLastImportViewManagerClass))

typedef struct _LastImportPageLastImportViewManager LastImportPageLastImportViewManager;
typedef struct _LastImportPageLastImportViewManagerClass LastImportPageLastImportViewManagerClass;
#define _view_collection_monitor_unref0(var) ((var == NULL) ? NULL : (var = (view_collection_monitor_unref (var), NULL)))
#define _view_manager_unref0(var) ((var == NULL) ? NULL : (var = (view_manager_unref (var), NULL)))

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;
typedef struct _ViewManagerPrivate ViewManagerPrivate;
typedef struct _CollectionViewManagerPrivate CollectionViewManagerPrivate;
typedef struct _LastImportPageLastImportViewManagerPrivate LastImportPageLastImportViewManagerPrivate;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

struct _Page {
	GtkScrolledWindow parent_instance;
	PagePrivate * priv;
	GtkUIManager* ui;
	GtkToolbar* toolbar;
	gboolean in_view;
};

struct _PageClass {
	GtkScrolledWindowClass parent_class;
	void (*set_page_name) (Page* self, const gchar* page_name);
	void (*set_container) (Page* self, GtkWindow* container);
	void (*clear_container) (Page* self);
	GtkMenuBar* (*get_menubar) (Page* self);
	GtkWidget* (*get_page_ui_widget) (Page* self, const gchar* path);
	GtkToolbar* (*get_toolbar) (Page* self);
	GtkMenu* (*get_page_context_menu) (Page* self);
	void (*switching_from) (Page* self);
	void (*switched_to) (Page* self);
	void (*ready) (Page* self);
	void (*switching_to_fullscreen) (Page* self, FullscreenWindow* fsw);
	void (*returning_from_fullscreen) (Page* self, FullscreenWindow* fsw);
	void (*init_collect_ui_filenames) (Page* self, GeeList* ui_filenames);
	GtkActionEntry* (*init_collect_action_entries) (Page* self, int* result_length1);
	GtkToggleActionEntry* (*init_collect_toggle_action_entries) (Page* self, int* result_length1);
	void (*register_radio_actions) (Page* self, GtkActionGroup* action_group);
	InjectionGroup** (*init_collect_injection_groups) (Page* self, int* result_length1);
	void (*init_actions) (Page* self, gint selected_count, gint count);
	void (*update_actions) (Page* self, gint selected_count, gint count);
	gboolean (*source_drag_failed) (Page* self, GdkDragContext* context, GtkDragResult drag_result);
	gboolean (*on_left_click) (Page* self, GdkEventButton* event);
	gboolean (*on_middle_click) (Page* self, GdkEventButton* event);
	gboolean (*on_right_click) (Page* self, GdkEventButton* event);
	gboolean (*on_left_released) (Page* self, GdkEventButton* event);
	gboolean (*on_middle_released) (Page* self, GdkEventButton* event);
	gboolean (*on_right_released) (Page* self, GdkEventButton* event);
	gboolean (*on_ctrl_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_ctrl_released) (Page* self, GdkEventKey* event);
	gboolean (*on_alt_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_alt_released) (Page* self, GdkEventKey* event);
	gboolean (*on_shift_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_shift_released) (Page* self, GdkEventKey* event);
	gboolean (*on_super_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_super_released) (Page* self, GdkEventKey* event);
	gboolean (*on_app_key_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_app_key_released) (Page* self, GdkEventKey* event);
	void (*on_move) (Page* self, GdkRectangle* rect);
	void (*on_move_start) (Page* self, GdkRectangle* rect);
	void (*on_move_finished) (Page* self, GdkRectangle* rect);
	void (*on_resize) (Page* self, GdkRectangle* rect);
	void (*on_resize_start) (Page* self, GdkRectangle* rect);
	void (*on_resize_finished) (Page* self, GdkRectangle* rect);
	gboolean (*on_configure) (Page* self, GdkEventConfigure* event, GdkRectangle* rect);
	gboolean (*on_motion) (Page* self, GdkEventMotion* event, gint x, gint y, GdkModifierType mask);
	gboolean (*on_leave_notify_event) (Page* self);
	gboolean (*on_mousewheel_up) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_down) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_left) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_right) (Page* self, GdkEventScroll* event);
	gboolean (*on_context_keypress) (Page* self);
	gboolean (*on_context_buttonpress) (Page* self, GdkEventButton* event);
	gboolean (*on_context_invoked) (Page* self);
	void (*set_page_cursor) (Page* self, GdkCursorType cursor_type);
};

typedef enum  {
	CHECKERBOARD_PAGE_ACTIVATOR_KEYBOARD,
	CHECKERBOARD_PAGE_ACTIVATOR_MOUSE
} CheckerboardPageActivator;

struct _CheckerboardPageKeyboardModifiers {
	gboolean ctrl_pressed;
	gboolean alt_pressed;
	gboolean shift_pressed;
	gboolean super_pressed;
};

struct _CheckerboardPage {
	Page parent_instance;
	CheckerboardPagePrivate * priv;
	CheckerboardItem* anchor;
	CheckerboardItem* cursor;
};

struct _CheckerboardPageClass {
	PageClass parent_class;
	GtkMenu* (*get_item_context_menu) (CheckerboardPage* self);
	gchar* (*get_view_empty_message) (CheckerboardPage* self);
	gchar* (*get_filter_no_match_message) (CheckerboardPage* self);
	void (*on_item_activated) (CheckerboardPage* self, CheckerboardItem* item, CheckerboardPageActivator activator, CheckerboardPageKeyboardModifiers* modifiers);
	SearchViewFilter* (*get_search_view_filter) (CheckerboardPage* self);
	CoreViewTracker* (*get_view_tracker) (CheckerboardPage* self);
	gboolean (*on_mouse_over) (CheckerboardPage* self, CheckerboardItem* item, gint x, gint y, GdkModifierType mask);
	void (*set_display_titles) (CheckerboardPage* self, gboolean display);
	void (*set_display_comments) (CheckerboardPage* self, gboolean display);
};

typedef enum  {
	RATING_REJECTED = -1,
	RATING_UNRATED = 0,
	RATING_ONE = 1,
	RATING_TWO = 2,
	RATING_THREE = 3,
	RATING_FOUR = 4,
	RATING_FIVE = 5
} Rating;

typedef enum  {
	RAW_DEVELOPER_SHOTWELL = 0,
	RAW_DEVELOPER_CAMERA,
	RAW_DEVELOPER_EMBEDDED
} RawDeveloper;

struct _MediaPage {
	CheckerboardPage parent_instance;
	MediaPagePrivate * priv;
};

struct _MediaPageClass {
	CheckerboardPageClass parent_class;
	void (*on_zoom_changed) (MediaPage* self);
	void (*on_export) (MediaPage* self);
	void (*on_increase_size) (MediaPage* self);
	void (*on_decrease_size) (MediaPage* self);
	void (*on_increase_rating) (MediaPage* self);
	void (*on_decrease_rating) (MediaPage* self);
	void (*on_set_rating) (MediaPage* self, Rating rating);
	void (*on_rate_rejected) (MediaPage* self);
	void (*on_rate_unrated) (MediaPage* self);
	void (*on_rate_one) (MediaPage* self);
	void (*on_rate_two) (MediaPage* self);
	void (*on_rate_three) (MediaPage* self);
	void (*on_rate_four) (MediaPage* self);
	void (*on_rate_five) (MediaPage* self);
	void (*on_move_to_trash) (MediaPage* self);
	void (*on_edit_title) (MediaPage* self);
	void (*on_edit_comment) (MediaPage* self);
	void (*on_display_titles) (MediaPage* self, GtkAction* action);
	void (*on_display_comments) (MediaPage* self, GtkAction* action);
	void (*on_display_ratings) (MediaPage* self, GtkAction* action);
	void (*on_display_tags) (MediaPage* self, GtkAction* action);
	void (*get_config_photos_sort) (MediaPage* self, gboolean* sort_order, gint* sort_by);
	void (*set_config_photos_sort) (MediaPage* self, gboolean sort_order, gint sort_by);
	void (*on_sort_changed) (MediaPage* self);
	void (*developer_changed) (MediaPage* self, RawDeveloper rd);
	DataView* (*create_thumbnail) (MediaPage* self, DataSource* source);
};

struct _CollectionPage {
	MediaPage parent_instance;
	CollectionPagePrivate * priv;
};

struct _CollectionPageClass {
	MediaPageClass parent_class;
};

struct _LastImportPage {
	CollectionPage parent_instance;
	LastImportPagePrivate * priv;
};

struct _LastImportPageClass {
	CollectionPageClass parent_class;
};

struct _ImportID {
	gint64 id;
};

struct _LastImportPagePrivate {
	ImportID last_import_id;
	Alteration* last_import_alteration;
};

typedef gboolean (*ProgressMonitor) (guint64 current, guint64 total, gboolean do_event_loop, void* user_data);
struct _ViewManager {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ViewManagerPrivate * priv;
};

struct _ViewManagerClass {
	GTypeClass parent_class;
	void (*finalize) (ViewManager *self);
	gboolean (*include_in_view) (ViewManager* self, DataSource* source);
	DataView* (*create_view) (ViewManager* self, DataSource* source);
};

struct _CollectionViewManager {
	ViewManager parent_instance;
	CollectionViewManagerPrivate * priv;
};

struct _CollectionViewManagerClass {
	ViewManagerClass parent_class;
};

struct _LastImportPageLastImportViewManager {
	CollectionViewManager parent_instance;
	LastImportPageLastImportViewManagerPrivate * priv;
};

struct _LastImportPageLastImportViewManagerClass {
	CollectionViewManagerClass parent_class;
};

struct _LastImportPageLastImportViewManagerPrivate {
	ImportID import_id;
};


static gpointer last_import_page_parent_class = NULL;
static gpointer last_import_page_last_import_view_manager_parent_class = NULL;

GType page_get_type (void) G_GNUC_CONST;
GType page_window_get_type (void) G_GNUC_CONST;
GType fullscreen_window_get_type (void) G_GNUC_CONST;
gpointer injection_group_ref (gpointer instance);
void injection_group_unref (gpointer instance);
GParamSpec* param_spec_injection_group (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_injection_group (GValue* value, gpointer v_object);
void value_take_injection_group (GValue* value, gpointer v_object);
gpointer value_get_injection_group (const GValue* value);
GType injection_group_get_type (void) G_GNUC_CONST;
GType checkerboard_page_get_type (void) G_GNUC_CONST;
GType data_object_get_type (void) G_GNUC_CONST;
GType data_view_get_type (void) G_GNUC_CONST;
GType thumbnail_view_get_type (void) G_GNUC_CONST;
GType checkerboard_item_get_type (void) G_GNUC_CONST;
GType checkerboard_page_activator_get_type (void) G_GNUC_CONST;
GType checkerboard_page_keyboard_modifiers_get_type (void) G_GNUC_CONST;
CheckerboardPageKeyboardModifiers* checkerboard_page_keyboard_modifiers_dup (const CheckerboardPageKeyboardModifiers* self);
void checkerboard_page_keyboard_modifiers_free (CheckerboardPageKeyboardModifiers* self);
gpointer view_filter_ref (gpointer instance);
void view_filter_unref (gpointer instance);
GParamSpec* param_spec_view_filter (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_view_filter (GValue* value, gpointer v_object);
void value_take_view_filter (GValue* value, gpointer v_object);
gpointer value_get_view_filter (const GValue* value);
GType view_filter_get_type (void) G_GNUC_CONST;
GType search_view_filter_get_type (void) G_GNUC_CONST;
gpointer core_tracker_ref (gpointer instance);
void core_tracker_unref (gpointer instance);
GParamSpec* core_param_spec_tracker (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void core_value_set_tracker (GValue* value, gpointer v_object);
void core_value_take_tracker (GValue* value, gpointer v_object);
gpointer core_value_get_tracker (const GValue* value);
GType core_tracker_get_type (void) G_GNUC_CONST;
GType core_view_tracker_get_type (void) G_GNUC_CONST;
GType media_page_get_type (void) G_GNUC_CONST;
GType rating_get_type (void) G_GNUC_CONST;
GType raw_developer_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType collection_page_get_type (void) G_GNUC_CONST;
GType last_import_page_get_type (void) G_GNUC_CONST;
GType import_id_get_type (void) G_GNUC_CONST;
ImportID* import_id_dup (const ImportID* self);
void import_id_free (ImportID* self);
gpointer alteration_ref (gpointer instance);
void alteration_unref (gpointer instance);
GParamSpec* param_spec_alteration (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_alteration (GValue* value, gpointer v_object);
void value_take_alteration (GValue* value, gpointer v_object);
gpointer value_get_alteration (const GValue* value);
GType alteration_get_type (void) G_GNUC_CONST;
#define LAST_IMPORT_PAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_LAST_IMPORT_PAGE, LastImportPagePrivate))
enum  {
	LAST_IMPORT_PAGE_DUMMY_PROPERTY
};
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_data_collection (GValue* value, gpointer v_object);
void value_take_data_collection (GValue* value, gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType source_collection_get_type (void) G_GNUC_CONST;
GType database_source_collection_get_type (void) G_GNUC_CONST;
GType media_source_collection_get_type (void) G_GNUC_CONST;
gpointer media_collection_registry_ref (gpointer instance);
void media_collection_registry_unref (gpointer instance);
GParamSpec* param_spec_media_collection_registry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_media_collection_registry (GValue* value, gpointer v_object);
void value_take_media_collection_registry (GValue* value, gpointer v_object);
gpointer value_get_media_collection_registry (const GValue* value);
GType media_collection_registry_get_type (void) G_GNUC_CONST;
MediaCollectionRegistry* media_collection_registry_get_instance (void);
GeeCollection* media_collection_registry_get_all (MediaCollectionRegistry* self);
static void last_import_page_on_import_rolls_altered (LastImportPage* self);
static void _last_import_page_on_import_rolls_altered_media_source_collection_import_roll_altered (MediaSourceCollection* _sender, gpointer self);
#define IMPORT_ID_INVALID ((gint64) 0)
void import_id_init (ImportID *self, gint64 id);
Alteration* alteration_new (const gchar* subject, const gchar* detail);
Alteration* alteration_construct (GType object_type, const gchar* subject, const gchar* detail);
#define LAST_IMPORT_PAGE_NAME _ ("Last Import")
LastImportPage* last_import_page_new (void);
LastImportPage* last_import_page_construct (GType object_type);
CollectionPage* collection_page_construct (GType object_type, const gchar* page_name);
ImportID* media_collection_registry_get_last_import_id (MediaCollectionRegistry* self);
GType view_collection_get_type (void) G_GNUC_CONST;
ViewCollection* page_get_view (Page* self);
void view_collection_halt_all_monitoring (ViewCollection* self);
void data_collection_clear (DataCollection* self);
gpointer view_manager_ref (gpointer instance);
void view_manager_unref (gpointer instance);
GParamSpec* param_spec_view_manager (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_view_manager (GValue* value, gpointer v_object);
void value_take_view_manager (GValue* value, gpointer v_object);
gpointer value_get_view_manager (const GValue* value);
GType view_manager_get_type (void) G_GNUC_CONST;
gpointer view_collection_monitor_ref (gpointer instance);
void view_collection_monitor_unref (gpointer instance);
GParamSpec* view_collection_param_spec_monitor (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void view_collection_value_set_monitor (GValue* value, gpointer v_object);
void view_collection_value_take_monitor (GValue* value, gpointer v_object);
gpointer view_collection_value_get_monitor (const GValue* value);
GType view_collection_monitor_get_type (void) G_GNUC_CONST;
ViewCollectionMonitor* view_collection_monitor_source_collection (ViewCollection* self, SourceCollection* sources, ViewManager* manager, Alteration* prereq, GeeCollection* initial, ProgressMonitor progress_monitor, void* progress_monitor_target);
static LastImportPageLastImportViewManager* last_import_page_last_import_view_manager_new (LastImportPage* owner, ImportID* import_id);
static LastImportPageLastImportViewManager* last_import_page_last_import_view_manager_construct (GType object_type, LastImportPage* owner, ImportID* import_id);
GType collection_view_manager_get_type (void) G_GNUC_CONST;
static GType last_import_page_last_import_view_manager_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void last_import_page_real_get_config_photos_sort (MediaPage* base, gboolean* sort_order, gint* sort_by);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
void configuration_facade_get_library_photos_sort (ConfigurationFacade* self, gboolean* sort_order, gint* sort_by);
static void last_import_page_real_set_config_photos_sort (MediaPage* base, gboolean sort_order, gint sort_by);
void configuration_facade_set_library_photos_sort (ConfigurationFacade* self, gboolean sort_order, gint sort_by);
#define LAST_IMPORT_PAGE_LAST_IMPORT_VIEW_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), LAST_IMPORT_PAGE_TYPE_LAST_IMPORT_VIEW_MANAGER, LastImportPageLastImportViewManagerPrivate))
enum  {
	LAST_IMPORT_PAGE_LAST_IMPORT_VIEW_MANAGER_DUMMY_PROPERTY
};
CollectionViewManager* collection_view_manager_new (CollectionPage* page);
CollectionViewManager* collection_view_manager_construct (GType object_type, CollectionPage* page);
static gboolean last_import_page_last_import_view_manager_real_include_in_view (ViewManager* base, DataSource* source);
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
void media_source_get_import_id (MediaSource* self, ImportID* result);
static void last_import_page_last_import_view_manager_finalize (ViewManager* obj);
static void last_import_page_finalize (GObject* obj);


static void _last_import_page_on_import_rolls_altered_media_source_collection_import_roll_altered (MediaSourceCollection* _sender, gpointer self) {
#line 41 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	last_import_page_on_import_rolls_altered ((LastImportPage*) self);
#line 715 "LastImportPage.c"
}


LastImportPage* last_import_page_construct (GType object_type) {
	LastImportPage * self = NULL;
#line 28 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	self = (LastImportPage*) collection_page_construct (object_type, LAST_IMPORT_PAGE_NAME);
#line 723 "LastImportPage.c"
	{
		GeeIterator* _col_it = NULL;
		MediaCollectionRegistry* _tmp0_ = NULL;
		MediaCollectionRegistry* _tmp1_ = NULL;
		GeeCollection* _tmp2_ = NULL;
		GeeCollection* _tmp3_ = NULL;
		GeeIterator* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp0_ = media_collection_registry_get_instance ();
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp1_ = _tmp0_;
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp2_ = media_collection_registry_get_all (_tmp1_);
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp3_ = _tmp2_;
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp4_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp5_ = _tmp4_;
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_g_object_unref0 (_tmp3_);
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_media_collection_registry_unref0 (_tmp1_);
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_col_it = _tmp5_;
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		while (TRUE) {
#line 752 "LastImportPage.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			MediaSourceCollection* col = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			MediaSourceCollection* _tmp10_ = NULL;
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp6_ = _col_it;
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			if (!_tmp7_) {
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
				break;
#line 767 "LastImportPage.c"
			}
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp8_ = _col_it;
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			col = (MediaSourceCollection*) _tmp9_;
#line 32 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp10_ = col;
#line 32 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			g_signal_connect_object (_tmp10_, "import-roll-altered", (GCallback) _last_import_page_on_import_rolls_altered_media_source_collection_import_roll_altered, self, 0);
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_data_collection_unref0 (col);
#line 781 "LastImportPage.c"
		}
#line 31 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_g_object_unref0 (_col_it);
#line 785 "LastImportPage.c"
	}
#line 36 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	last_import_page_on_import_rolls_altered (self);
#line 27 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	return self;
#line 791 "LastImportPage.c"
}


LastImportPage* last_import_page_new (void) {
#line 27 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	return last_import_page_construct (TYPE_LAST_IMPORT_PAGE);
#line 798 "LastImportPage.c"
}


static void last_import_page_on_import_rolls_altered (LastImportPage* self) {
	ImportID* current_last_import_id = NULL;
	MediaCollectionRegistry* _tmp0_ = NULL;
	MediaCollectionRegistry* _tmp1_ = NULL;
	ImportID* _tmp2_ = NULL;
	ImportID* _tmp3_ = NULL;
	ImportID* _tmp4_ = NULL;
	ImportID* _tmp9_ = NULL;
	gint64 _tmp10_ = 0LL;
	ImportID _tmp11_ = {0};
	gint64 _tmp12_ = 0LL;
	ImportID* _tmp13_ = NULL;
	ViewCollection* _tmp14_ = NULL;
	ViewCollection* _tmp15_ = NULL;
	ViewCollection* _tmp16_ = NULL;
	ViewCollection* _tmp17_ = NULL;
#line 45 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	g_return_if_fail (IS_LAST_IMPORT_PAGE (self));
#line 47 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp0_ = media_collection_registry_get_instance ();
#line 47 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp1_ = _tmp0_;
#line 47 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp2_ = media_collection_registry_get_last_import_id (_tmp1_);
#line 47 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp3_ = _tmp2_;
#line 47 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_media_collection_registry_unref0 (_tmp1_);
#line 47 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	current_last_import_id = _tmp3_;
#line 50 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp4_ = current_last_import_id;
#line 50 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	if (_tmp4_ == NULL) {
#line 836 "LastImportPage.c"
		ViewCollection* _tmp5_ = NULL;
		ViewCollection* _tmp6_ = NULL;
		ViewCollection* _tmp7_ = NULL;
		ViewCollection* _tmp8_ = NULL;
#line 51 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp5_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 51 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp6_ = _tmp5_;
#line 51 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		view_collection_halt_all_monitoring (_tmp6_);
#line 51 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_data_collection_unref0 (_tmp6_);
#line 52 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp7_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 52 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp8_ = _tmp7_;
#line 52 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		data_collection_clear (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_DATA_COLLECTION, DataCollection));
#line 52 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_data_collection_unref0 (_tmp8_);
#line 54 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_import_id_free0 (current_last_import_id);
#line 54 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		return;
#line 861 "LastImportPage.c"
	}
#line 57 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp9_ = current_last_import_id;
#line 57 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp10_ = (*_tmp9_).id;
#line 57 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp11_ = self->priv->last_import_id;
#line 57 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp12_ = _tmp11_.id;
#line 57 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	if (_tmp10_ == _tmp12_) {
#line 58 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_import_id_free0 (current_last_import_id);
#line 58 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		return;
#line 877 "LastImportPage.c"
	}
#line 60 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp13_ = current_last_import_id;
#line 60 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	self->priv->last_import_id = *_tmp13_;
#line 62 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp14_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 62 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp15_ = _tmp14_;
#line 62 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	view_collection_halt_all_monitoring (_tmp15_);
#line 62 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_data_collection_unref0 (_tmp15_);
#line 63 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp16_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 63 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp17_ = _tmp16_;
#line 63 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	data_collection_clear (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, TYPE_DATA_COLLECTION, DataCollection));
#line 63 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_data_collection_unref0 (_tmp17_);
#line 899 "LastImportPage.c"
	{
		GeeIterator* _col_it = NULL;
		MediaCollectionRegistry* _tmp18_ = NULL;
		MediaCollectionRegistry* _tmp19_ = NULL;
		GeeCollection* _tmp20_ = NULL;
		GeeCollection* _tmp21_ = NULL;
		GeeIterator* _tmp22_ = NULL;
		GeeIterator* _tmp23_ = NULL;
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp18_ = media_collection_registry_get_instance ();
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp19_ = _tmp18_;
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp20_ = media_collection_registry_get_all (_tmp19_);
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp21_ = _tmp20_;
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp22_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GEE_TYPE_ITERABLE, GeeIterable));
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp23_ = _tmp22_;
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_g_object_unref0 (_tmp21_);
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_media_collection_registry_unref0 (_tmp19_);
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_col_it = _tmp23_;
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		while (TRUE) {
#line 928 "LastImportPage.c"
			GeeIterator* _tmp24_ = NULL;
			gboolean _tmp25_ = FALSE;
			MediaSourceCollection* col = NULL;
			GeeIterator* _tmp26_ = NULL;
			gpointer _tmp27_ = NULL;
			ViewCollection* _tmp28_ = NULL;
			ViewCollection* _tmp29_ = NULL;
			MediaSourceCollection* _tmp30_ = NULL;
			ImportID _tmp31_ = {0};
			LastImportPageLastImportViewManager* _tmp32_ = NULL;
			LastImportPageLastImportViewManager* _tmp33_ = NULL;
			Alteration* _tmp34_ = NULL;
			ViewCollectionMonitor* _tmp35_ = NULL;
			ViewCollectionMonitor* _tmp36_ = NULL;
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp24_ = _col_it;
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp25_ = gee_iterator_next (_tmp24_);
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			if (!_tmp25_) {
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
				break;
#line 951 "LastImportPage.c"
			}
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp26_ = _col_it;
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp27_ = gee_iterator_get (_tmp26_);
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			col = (MediaSourceCollection*) _tmp27_;
#line 66 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp28_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 66 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp29_ = _tmp28_;
#line 66 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp30_ = col;
#line 66 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp31_ = self->priv->last_import_id;
#line 66 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp32_ = last_import_page_last_import_view_manager_new (self, &_tmp31_);
#line 66 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp33_ = _tmp32_;
#line 66 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp34_ = self->priv->last_import_alteration;
#line 66 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp35_ = view_collection_monitor_source_collection (_tmp29_, G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, TYPE_SOURCE_COLLECTION, SourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, TYPE_VIEW_MANAGER, ViewManager), _tmp34_, NULL, NULL, NULL);
#line 66 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp36_ = _tmp35_;
#line 66 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_view_collection_monitor_unref0 (_tmp36_);
#line 66 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_view_manager_unref0 (_tmp33_);
#line 66 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_data_collection_unref0 (_tmp29_);
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_data_collection_unref0 (col);
#line 985 "LastImportPage.c"
		}
#line 65 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_g_object_unref0 (_col_it);
#line 989 "LastImportPage.c"
	}
#line 45 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_import_id_free0 (current_last_import_id);
#line 993 "LastImportPage.c"
}


static void last_import_page_real_get_config_photos_sort (MediaPage* base, gboolean* sort_order, gint* sort_by) {
	LastImportPage * self;
	gboolean _vala_sort_order = FALSE;
	gint _vala_sort_by = 0;
	ConfigFacade* _tmp0_ = NULL;
	ConfigFacade* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gint _tmp3_ = 0;
#line 71 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LAST_IMPORT_PAGE, LastImportPage);
#line 72 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp0_ = config_facade_get_instance ();
#line 72 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp1_ = _tmp0_;
#line 72 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	configuration_facade_get_library_photos_sort (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), &_tmp2_, &_tmp3_);
#line 72 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_vala_sort_order = _tmp2_;
#line 72 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_vala_sort_by = _tmp3_;
#line 72 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_g_object_unref0 (_tmp1_);
#line 71 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	if (sort_order) {
#line 71 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		*sort_order = _vala_sort_order;
#line 1023 "LastImportPage.c"
	}
#line 71 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	if (sort_by) {
#line 71 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		*sort_by = _vala_sort_by;
#line 1029 "LastImportPage.c"
	}
}


static void last_import_page_real_set_config_photos_sort (MediaPage* base, gboolean sort_order, gint sort_by) {
	LastImportPage * self;
	ConfigFacade* _tmp0_ = NULL;
	ConfigFacade* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gint _tmp3_ = 0;
#line 75 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LAST_IMPORT_PAGE, LastImportPage);
#line 76 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp0_ = config_facade_get_instance ();
#line 76 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp1_ = _tmp0_;
#line 76 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp2_ = sort_order;
#line 76 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp3_ = sort_by;
#line 76 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	configuration_facade_set_library_photos_sort (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_, _tmp3_);
#line 76 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_g_object_unref0 (_tmp1_);
#line 1054 "LastImportPage.c"
}


static LastImportPageLastImportViewManager* last_import_page_last_import_view_manager_construct (GType object_type, LastImportPage* owner, ImportID* import_id) {
	LastImportPageLastImportViewManager* self = NULL;
	LastImportPage* _tmp0_ = NULL;
	ImportID _tmp1_ = {0};
#line 13 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	g_return_val_if_fail (IS_LAST_IMPORT_PAGE (owner), NULL);
#line 13 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	g_return_val_if_fail (import_id != NULL, NULL);
#line 14 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp0_ = owner;
#line 14 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	self = (LastImportPageLastImportViewManager*) collection_view_manager_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_COLLECTION_PAGE, CollectionPage));
#line 16 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp1_ = *import_id;
#line 16 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	self->priv->import_id = _tmp1_;
#line 13 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	return self;
#line 1076 "LastImportPage.c"
}


static LastImportPageLastImportViewManager* last_import_page_last_import_view_manager_new (LastImportPage* owner, ImportID* import_id) {
#line 13 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	return last_import_page_last_import_view_manager_construct (LAST_IMPORT_PAGE_TYPE_LAST_IMPORT_VIEW_MANAGER, owner, import_id);
#line 1083 "LastImportPage.c"
}


static gboolean last_import_page_last_import_view_manager_real_include_in_view (ViewManager* base, DataSource* source) {
	LastImportPageLastImportViewManager * self;
	gboolean result = FALSE;
	DataSource* _tmp0_ = NULL;
	ImportID _tmp1_ = {0};
	gint64 _tmp2_ = 0LL;
	ImportID _tmp3_ = {0};
	gint64 _tmp4_ = 0LL;
#line 19 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LAST_IMPORT_PAGE_TYPE_LAST_IMPORT_VIEW_MANAGER, LastImportPageLastImportViewManager);
#line 19 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	g_return_val_if_fail (IS_DATA_SOURCE (source), FALSE);
#line 20 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp0_ = source;
#line 20 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	media_source_get_import_id (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_MEDIA_SOURCE, MediaSource), &_tmp1_);
#line 20 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp2_ = _tmp1_.id;
#line 20 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp3_ = self->priv->import_id;
#line 20 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp4_ = _tmp3_.id;
#line 20 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	result = _tmp2_ == _tmp4_;
#line 20 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	return result;
#line 1113 "LastImportPage.c"
}


static void last_import_page_last_import_view_manager_class_init (LastImportPageLastImportViewManagerClass * klass) {
#line 10 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	last_import_page_last_import_view_manager_parent_class = g_type_class_peek_parent (klass);
#line 10 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	((ViewManagerClass *) klass)->finalize = last_import_page_last_import_view_manager_finalize;
#line 10 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	g_type_class_add_private (klass, sizeof (LastImportPageLastImportViewManagerPrivate));
#line 10 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	((ViewManagerClass *) klass)->include_in_view = last_import_page_last_import_view_manager_real_include_in_view;
#line 1126 "LastImportPage.c"
}


static void last_import_page_last_import_view_manager_instance_init (LastImportPageLastImportViewManager * self) {
#line 10 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	self->priv = LAST_IMPORT_PAGE_LAST_IMPORT_VIEW_MANAGER_GET_PRIVATE (self);
#line 1133 "LastImportPage.c"
}


static void last_import_page_last_import_view_manager_finalize (ViewManager* obj) {
	LastImportPageLastImportViewManager * self;
#line 10 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LAST_IMPORT_PAGE_TYPE_LAST_IMPORT_VIEW_MANAGER, LastImportPageLastImportViewManager);
#line 10 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	VIEW_MANAGER_CLASS (last_import_page_last_import_view_manager_parent_class)->finalize (obj);
#line 1143 "LastImportPage.c"
}


static GType last_import_page_last_import_view_manager_get_type (void) {
	static volatile gsize last_import_page_last_import_view_manager_type_id__volatile = 0;
	if (g_once_init_enter (&last_import_page_last_import_view_manager_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LastImportPageLastImportViewManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) last_import_page_last_import_view_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LastImportPageLastImportViewManager), 0, (GInstanceInitFunc) last_import_page_last_import_view_manager_instance_init, NULL };
		GType last_import_page_last_import_view_manager_type_id;
		last_import_page_last_import_view_manager_type_id = g_type_register_static (TYPE_COLLECTION_VIEW_MANAGER, "LastImportPageLastImportViewManager", &g_define_type_info, 0);
		g_once_init_leave (&last_import_page_last_import_view_manager_type_id__volatile, last_import_page_last_import_view_manager_type_id);
	}
	return last_import_page_last_import_view_manager_type_id__volatile;
}


static void last_import_page_class_init (LastImportPageClass * klass) {
#line 7 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	last_import_page_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	g_type_class_add_private (klass, sizeof (LastImportPagePrivate));
#line 7 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	((MediaPageClass *) klass)->get_config_photos_sort = last_import_page_real_get_config_photos_sort;
#line 7 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	((MediaPageClass *) klass)->set_config_photos_sort = last_import_page_real_set_config_photos_sort;
#line 7 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	G_OBJECT_CLASS (klass)->finalize = last_import_page_finalize;
#line 1170 "LastImportPage.c"
}


static void last_import_page_instance_init (LastImportPage * self) {
	Alteration* _tmp0_ = NULL;
#line 7 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	self->priv = LAST_IMPORT_PAGE_GET_PRIVATE (self);
#line 24 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	import_id_init (&self->priv->last_import_id, IMPORT_ID_INVALID);
#line 25 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_tmp0_ = alteration_new ("metadata", "import-id");
#line 25 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	self->priv->last_import_alteration = _tmp0_;
#line 1184 "LastImportPage.c"
}


static void last_import_page_finalize (GObject* obj) {
	LastImportPage * self;
#line 7 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LAST_IMPORT_PAGE, LastImportPage);
#line 1192 "LastImportPage.c"
	{
		GeeIterator* _col_it = NULL;
		MediaCollectionRegistry* _tmp0_ = NULL;
		MediaCollectionRegistry* _tmp1_ = NULL;
		GeeCollection* _tmp2_ = NULL;
		GeeCollection* _tmp3_ = NULL;
		GeeIterator* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp0_ = media_collection_registry_get_instance ();
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp1_ = _tmp0_;
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp2_ = media_collection_registry_get_all (_tmp1_);
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp3_ = _tmp2_;
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp4_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_tmp5_ = _tmp4_;
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_g_object_unref0 (_tmp3_);
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_media_collection_registry_unref0 (_tmp1_);
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_col_it = _tmp5_;
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		while (TRUE) {
#line 1221 "LastImportPage.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			MediaSourceCollection* col = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			MediaSourceCollection* _tmp10_ = NULL;
			guint _tmp11_ = 0U;
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp6_ = _col_it;
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			if (!_tmp7_) {
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
				break;
#line 1237 "LastImportPage.c"
			}
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp8_ = _col_it;
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			col = (MediaSourceCollection*) _tmp9_;
#line 41 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_tmp10_ = col;
#line 41 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			g_signal_parse_name ("import-roll-altered", TYPE_MEDIA_SOURCE_COLLECTION, &_tmp11_, NULL, FALSE);
#line 41 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			g_signal_handlers_disconnect_matched (_tmp10_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp11_, 0, NULL, (GCallback) _last_import_page_on_import_rolls_altered_media_source_collection_import_roll_altered, self);
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
			_data_collection_unref0 (col);
#line 1253 "LastImportPage.c"
		}
#line 40 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
		_g_object_unref0 (_col_it);
#line 1257 "LastImportPage.c"
	}
#line 25 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	_alteration_unref0 (self->priv->last_import_alteration);
#line 7 "/home/jens/Source/shotwell/src/library/LastImportPage.vala"
	G_OBJECT_CLASS (last_import_page_parent_class)->finalize (obj);
#line 1263 "LastImportPage.c"
}


GType last_import_page_get_type (void) {
	static volatile gsize last_import_page_type_id__volatile = 0;
	if (g_once_init_enter (&last_import_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LastImportPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) last_import_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LastImportPage), 0, (GInstanceInitFunc) last_import_page_instance_init, NULL };
		GType last_import_page_type_id;
		last_import_page_type_id = g_type_register_static (TYPE_COLLECTION_PAGE, "LastImportPage", &g_define_type_info, 0);
		g_once_init_leave (&last_import_page_type_id__volatile, last_import_page_type_id);
	}
	return last_import_page_type_id__volatile;
}



